timespantools.timespan_2_stops_when_timespan_1_stops
====================================================

.. autofunction:: abjad.tools.timespantools.timespan_2_stops_when_timespan_1_stops.timespan_2_stops_when_timespan_1_stops
